hlvox package
=============

Submodules
----------

hlvox.manager module
--------------------

.. automodule:: hlvox.manager
    :members:
    :undoc-members:
    :show-inheritance:

hlvox.voice module
------------------

.. automodule:: hlvox.voice
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hlvox
    :members:
    :undoc-members:
    :show-inheritance:
